==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QLevelOfDetailSwitch.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a way of enabling child entities based on distance or screen size</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qlevelofdetailswitch.html">Qt3DRender::QLevelOfDetailSwitch</a></p>
 */
public class QLevelOfDetailSwitch extends io.qt.qt3d.render.QLevelOfDetail
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLevelOfDetailSwitch.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLevelOfDetailSwitch(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLevelOfDetailSwitch() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlevelofdetailswitch.html#QLevelOfDetailSwitch">Qt3DRender::QLevelOfDetailSwitch::QLevelOfDetailSwitch(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLevelOfDetailSwitch(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLevelOfDetailSwitch instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLevelOfDetailSwitch(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLevelOfDetailSwitch(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLevelOfDetailSwitch instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.6-sources.jar: io/qt/qt3d/render/QLevelOfDetailSwitch.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a way of enabling child entities based on distance or screen size</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qlevelofdetailswitch.html">Qt3DRender::QLevelOfDetailSwitch</a></p>
 */
public class QLevelOfDetailSwitch extends io.qt.qt3d.render.QLevelOfDetail
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLevelOfDetailSwitch.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLevelOfDetailSwitch(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLevelOfDetailSwitch() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlevelofdetailswitch.html#QLevelOfDetailSwitch">Qt3DRender::QLevelOfDetailSwitch::QLevelOfDetailSwitch(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLevelOfDetailSwitch(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLevelOfDetailSwitch instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLevelOfDetailSwitch(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLevelOfDetailSwitch(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLevelOfDetailSwitch instance, QDeclarativeConstructor constructor);
    
}
